lpc: Rename reset_lpc to lpc_reset

Change-Id: Iee234830b7ea93a7c51b45217d87162e14ef56ee
Signed-off-by: Andrew Jeffery <andrew@aj.id.au>
diff --git a/lpc_reset.c b/lpc_reset.c
index 73fd214..b1e7939 100644
--- a/lpc_reset.c
+++ b/lpc_reset.c
@@ -7,12 +7,12 @@
 #include "lpc.h"
 
 /*
  * reset_lpc() - Reset the lpc bus mapping
  * @context:	The mbox context pointer
  *
  * Return:	0 on success otherwise negative error code
  */
-int reset_lpc(struct mbox_context *context)
+int lpc_reset(struct mbox_context *context)
 {
 	return lpc_map_flash(context);
 }
@@ -7,12 +7,12 @@
 
 /*
- * reset_lpc() - Reset the lpc bus mapping
+ * lpc_reset() - Reset the lpc bus mapping
  * @context:	The mbox context pointer
  *